==> tecfy_core_package-1.0.41.tar.gz: lib/views/components/home/tool_bar.componenet.dart <==
part of tecfy_core_client_package;

class ToolBarComponenet extends StatefulWidget {
  @override
  _ToolBarComponenetState createState() => _ToolBarComponenetState();
}

class _ToolBarComponenetState extends AppState<ToolBarComponenet> {
  double get _height => 45;
  @override
  Widget build(BuildContext context) {
    return Card(
      elevation: 10,
      margin: EdgeInsets.all(10),
      child: Row(
        children: <Widget>[
          TecfyBasicApp.isTest ? Container() : SizedBox(width: 10),
          TecfyBasicApp.isTest
              ? Container()
              : CircleAvatar(
                  radius: 18, backgroundColor: ThemeService.mainColor),
          TecfyBasicApp.isTest ? Container() : SizedBox(width: 10),
          TecfyBasicApp.isTest
              ? Container()
              : Text(AppLocale.translate('Welcome'),
                  style: TextStyle(color: ThemeService.subColor)),
          TecfyBasicApp.isTest
              ? Container()
              : Text(',', style: TextStyle(color: ThemeService.subColor)),
          TecfyBasicApp.isTest ? Container() : SizedBox(width: 2),
          Expanded(
            child: Text(
              LocalConfigService.user?.fullName ?? AppLocale.translate('Guest'),
              maxLines: 1,
            ),
          ),
          MaterialButton(
              padding: EdgeInsets.all(0),
              child: Text(AppLocale.translate('Logout'),
                  style: TextStyle(color: ThemeService.dangerColor)),
              onPressed: () => AccountService.signout(context)),
          IconButton(
              tooltip: trans('Lock'),
              onPressed: () => AccountService.lock(context),
              icon: Icon(Icons.lock, color: ThemeService.textSubColor)),
          Container(
              width: 0.5, height: _height, color: ThemeService.textSubColor),
          SizedBox(width: 2),
          IconButton(
              tooltip: trans('Main Page'),
              onPressed: () => AppNavigator.navigateTo(
                  context, () => DashboardPage(),
                  replaceAll: true),
              icon: Icon(Icons.home, color: ThemeService.textSubColor)),
          SizedBox(width: 2),
          Container(
              width: 0.5, height: _height, color: ThemeService.textSubColor),
          SizedBox(width: 2),
          IconButton(
              tooltip: trans('Chat'),
              onPressed: () => AppNavigator.navigateTo(
                  context, () => ChatContactsPage(),
                  animationType: AnimationTypes.opacity),
              icon: Icon(Icons.markunread, color: ThemeService.textSubColor)),
          SizedBox(width: 2),
          Container(
              width: 0.5, height: _height, color: ThemeService.textSubColor),
          SizedBox(width: 2),
          NotificationIcon(color: ThemeService.textSubColor),
          SizedBox(width: 2),
          Container(
              width: 0.5, height: _height, color: ThemeService.textSubColor),
          SizedBox(width: 2),
          SettingIcon(color: ThemeService.textSubColor)
        ],
      ),
    );
  }
}

==> tecfy_core_package-1.1.6.tar.gz: lib/views/components/home/tool_bar.componenet.dart <==
part of tecfy_core_client_package;

class ToolBarComponenet extends StatefulWidget {
  @override
  _ToolBarComponenetState createState() => _ToolBarComponenetState();
}

class _ToolBarComponenetState extends AppState<ToolBarComponenet> {
  double get _height => 45;
  @override
  Widget build(BuildContext context) {
    return Card(
      elevation: 10,
      margin: EdgeInsets.all(10),
      child: Row(
        children: <Widget>[
          TecfyBasicApp.isTest ? Container() : SizedBox(width: 10),
          TecfyBasicApp.isTest
              ? Container()
              : CircleAvatar(
                  radius: 18, backgroundColor: ThemeService.mainColor),
          TecfyBasicApp.isTest ? Container() : SizedBox(width: 10),
          TecfyBasicApp.isTest
              ? Container()
              : Text(AppLocale.translate('Welcome'),
                  style: TextStyle(color: ThemeService.subColor)),
          TecfyBasicApp.isTest
              ? Container()
              : Text(',', style: TextStyle(color: ThemeService.subColor)),
          TecfyBasicApp.isTest ? Container() : SizedBox(width: 2),
          Expanded(
            child: Text(
              LocalConfigService.user?.fullName ?? AppLocale.translate('Guest'),
              maxLines: 1,
            ),
          ),
          MaterialButton(
              padding: EdgeInsets.all(0),
              child: Text(AppLocale.translate('Logout'),
                  style: TextStyle(color: ThemeService.dangerColor)),
              onPressed: () => AccountService.signout(context)),
          IconButton(
              tooltip: trans('Lock'),
              onPressed: () => AccountService.lock(context),
              icon: Icon(Icons.lock, color: ThemeService.textSubColor)),
          Container(
              width: 0.5, height: _height, color: ThemeService.textSubColor),
          SizedBox(width: 2),
          IconButton(
              tooltip: trans('Main Page'),
              onPressed: () => AppNavigator.navigateTo(
                  context, () => DashboardPage(),
                  replaceAll: true),
              icon: Icon(Icons.home, color: ThemeService.textSubColor)),
          // SizedBox(width: 2),
          // Container(
          //     width: 0.5, height: _height, color: ThemeService.textSubColor),
          // // SizedBox(width: 2),
          // // IconButton(
          // //     tooltip: trans('Chat'),
          // //     onPressed: () => AppNavigator.navigateTo(
          // //         context, () => ChatContactsPage(),
          // //         animationType: AnimationTypes.opacity),
          // //     icon: Icon(Icons.markunread, color: ThemeService.textSubColor)),
          SizedBox(width: 2),
          Container(
              width: 0.5, height: _height, color: ThemeService.textSubColor),
          SizedBox(width: 2),
          NotificationIcon(color: ThemeService.textSubColor),
          SizedBox(width: 2),
          Container(
              width: 0.5, height: _height, color: ThemeService.textSubColor),
          SizedBox(width: 2),
          SettingIcon(color: ThemeService.textSubColor)
        ],
      ),
    );
  }
}
